@@ -1,7 +1,7 @@
 #
 # This file is part of PCAP BGP Parser (pbgpp)
 #
-# Copyright 2016 DE-CIX Management GmbH
+# Copyright 2016-2017 DE-CIX Management GmbH
 # Author: Tobias Hannaske <tobias.hannaske@de-cix.net>
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -131,6 +131,8 @@ class BGPTranslation:
                 return "Long-lived graceful restart (LLGR) capability"
             elif value == BGPStatics.CAPABILITY_FQDN:
                 return "FQDN capability"
+            elif value == BGPStatics.CAPABILITY_ALTERNATIVE_ROUTE_REFRESH:
+                return "Route refresh capability (Cisco-legacy)"
             else:
                 return "Unknown"
         except Exception as e:
