@@ -85,6 +85,13 @@ class BGPPacket:
         # Check for empty list (in this case we have a malformed/non-BGP packet)
         if len(messages) == 0:
             raise BGPPacketHasNoMessagesError("parsed packet didn't contain any BGP messages")
+        elif self.payload[
+             0:16] != b'\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff':  # len(messages) >= 1
+            # Check if the payload starts with the magic marker. If not we have to trash that bytes as it's
+            # a result of a missing TCP stream reassembly
+            messages.pop(0)
+        else:
+            pass  # contains only valid messages
 
         # Now iterate through the found messages ...
         for m in messages:
